==> org-lsst-ccs-ui-1.2.4-sources.jar: org/lsst/ccs/plugin/jas3/dictionary/HTMLTextPane.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

package org.lsst.ccs.plugin.jas3.dictionary;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.JTextPane;
import javax.swing.text.BadLocationException;
import javax.swing.text.html.HTML;
import javax.swing.text.html.HTMLDocument;
import javax.swing.text.html.HTMLEditorKit;

/**
 *
 * @author emarin
 */
public class HTMLTextPane extends JTextPane {

    private static final int MAX_LENGTH = 10000;
    HTMLEditorKit kit;
    HTMLDocument doc;
    
    public HTMLTextPane() {
        setEditable(false);
        kit = new HTMLEditorKit();
        doc = new HTMLDocument();
        this.setEditorKit(kit);
        this.setDocument(doc);
    }
    
    public void insertHTML(String s){
        try {
            kit.insertHTML(doc, doc.getLength(), s, 0, 0, null);
            int overLength=doc.getLength() - MAX_LENGTH;
            if (overLength > 0){
                removeOverLength(overLength);
            }
        } catch (BadLocationException ex) {
            Logger.getLogger(HTMLTextPane.class.getName()).log(Level.SEVERE, null, ex);
        } catch (IOException ex) {
            Logger.getLogger(HTMLTextPane.class.getName()).log(Level.SEVERE, null, ex);
        }
    }
    
    private void removeOverLength(int overLength) throws BadLocationException{
                doc.remove(0,overLength);
    }
    
}

==> org-lsst-ccs-ui-1.3.4-sources.jar: org/lsst/ccs/plugin/jas3/dictionary/HTMLTextPane.java <==
package org.lsst.ccs.plugin.jas3.dictionary;

import java.awt.Font;
import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.JTextPane;
import javax.swing.text.BadLocationException;
import javax.swing.text.html.HTMLDocument;
import javax.swing.text.html.HTMLEditorKit;

/**
 *
 * @author emarin
 */
public class HTMLTextPane extends JTextPane {

    private static final int MAX_LENGTH = 10000;
    HTMLEditorKit kit;
    HTMLDocument doc;
    
    public HTMLTextPane() {
        setEditable(false);
        kit = new HTMLEditorKit();
        doc = new HTMLDocument();
        this.setEditorKit(kit);

        // Font management
        Font font = new Font(Font.MONOSPACED, Font.PLAIN, 15);
        String bodyrule = "body { font-family: " + font.getFamily() + "; " + 
                "font-size: " + font.getSize() + "pt;}";
        doc.getStyleSheet().addRule(bodyrule);
        this.setDocument(doc);
        
        
    }
    
    public void insertHTML(String s){
        try {
            kit.insertHTML(doc, doc.getLength(), s, 0, 0, null);
            int overLength=doc.getLength() - MAX_LENGTH;
            if (overLength > 0){
                removeOverLength(overLength);
            }
        } catch (BadLocationException ex) {
            Logger.getLogger(HTMLTextPane.class.getName()).log(Level.SEVERE, null, ex);
        } catch (IOException ex) {
            Logger.getLogger(HTMLTextPane.class.getName()).log(Level.SEVERE, null, ex);
        }
    }
    
    private void removeOverLength(int overLength) throws BadLocationException{
                doc.remove(0,overLength);
    }
    
}
